@@ -14,12 +14,15 @@ def _get_kwargs(
     path: str,
     *,
     decrypt_secret: Union[Unset, None, bool] = UNSET,
+    include_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
     params: Dict[str, Any] = {}
     params["decrypt_secret"] = decrypt_secret
 
+    params["include_encrypted"] = include_encrypted
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -62,6 +65,7 @@ def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     decrypt_secret: Union[Unset, None, bool] = UNSET,
+    include_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Response[GetVariableResponse200]:
     """get variable
 
@@ -69,6 +73,7 @@ def sync_detailed(
         workspace (str):
         path (str):
         decrypt_secret (Union[Unset, None, bool]):
+        include_encrypted (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -82,6 +87,7 @@ def sync_detailed(
         workspace=workspace,
         path=path,
         decrypt_secret=decrypt_secret,
+        include_encrypted=include_encrypted,
     )
 
     response = client.get_httpx_client().request(
@@ -97,6 +103,7 @@ def sync(
     *,
     client: Union[AuthenticatedClient, Client],
     decrypt_secret: Union[Unset, None, bool] = UNSET,
+    include_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Optional[GetVariableResponse200]:
     """get variable
 
@@ -104,6 +111,7 @@ def sync(
         workspace (str):
         path (str):
         decrypt_secret (Union[Unset, None, bool]):
+        include_encrypted (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -118,6 +126,7 @@ def sync(
         path=path,
         client=client,
         decrypt_secret=decrypt_secret,
+        include_encrypted=include_encrypted,
     ).parsed
 
 
@@ -127,6 +136,7 @@ async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     decrypt_secret: Union[Unset, None, bool] = UNSET,
+    include_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Response[GetVariableResponse200]:
     """get variable
 
@@ -134,6 +144,7 @@ async def asyncio_detailed(
         workspace (str):
         path (str):
         decrypt_secret (Union[Unset, None, bool]):
+        include_encrypted (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -147,6 +158,7 @@ async def asyncio_detailed(
         workspace=workspace,
         path=path,
         decrypt_secret=decrypt_secret,
+        include_encrypted=include_encrypted,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -160,6 +172,7 @@ async def asyncio(
     *,
     client: Union[AuthenticatedClient, Client],
     decrypt_secret: Union[Unset, None, bool] = UNSET,
+    include_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Optional[GetVariableResponse200]:
     """get variable
 
@@ -167,6 +180,7 @@ async def asyncio(
         workspace (str):
         path (str):
         decrypt_secret (Union[Unset, None, bool]):
+        include_encrypted (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -182,5 +196,6 @@ async def asyncio(
             path=path,
             client=client,
             decrypt_secret=decrypt_secret,
+            include_encrypted=include_encrypted,
         )
     ).parsed
