@@ -16,12 +16,14 @@ class ConnectCallbackResponse200:
         expires_in (Union[Unset, int]):
         refresh_token (Union[Unset, str]):
         scope (Union[Unset, List[str]]):
+        grant_type (Union[Unset, str]):
     """
 
     access_token: str
     expires_in: Union[Unset, int] = UNSET
     refresh_token: Union[Unset, str] = UNSET
     scope: Union[Unset, List[str]] = UNSET
+    grant_type: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -32,6 +34,8 @@ class ConnectCallbackResponse200:
         if not isinstance(self.scope, Unset):
             scope = self.scope
 
+        grant_type = self.grant_type
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -45,6 +49,8 @@ class ConnectCallbackResponse200:
             field_dict["refresh_token"] = refresh_token
         if scope is not UNSET:
             field_dict["scope"] = scope
+        if grant_type is not UNSET:
+            field_dict["grant_type"] = grant_type
 
         return field_dict
 
@@ -59,11 +65,14 @@ class ConnectCallbackResponse200:
 
         scope = cast(List[str], d.pop("scope", UNSET))
 
+        grant_type = d.pop("grant_type", UNSET)
+
         connect_callback_response_200 = cls(
             access_token=access_token,
             expires_in=expires_in,
             refresh_token=refresh_token,
             scope=scope,
+            grant_type=grant_type,
         )
 
         connect_callback_response_200.additional_properties = d
