@@ -15,17 +15,27 @@ class CreateAccountJsonBody:
         expires_in (int):
         client (str):
         refresh_token (Union[Unset, str]):
+        grant_type (Union[Unset, str]):  Default: 'authorization_code'.
+        cc_client_id (Union[Unset, str]): OAuth client ID for resource-level credentials (client_credentials flow only)
+        cc_client_secret (Union[Unset, str]): OAuth client secret for resource-level credentials (client_credentials
+            flow only)
     """
 
     expires_in: int
     client: str
     refresh_token: Union[Unset, str] = UNSET
+    grant_type: Union[Unset, str] = "authorization_code"
+    cc_client_id: Union[Unset, str] = UNSET
+    cc_client_secret: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         expires_in = self.expires_in
         client = self.client
         refresh_token = self.refresh_token
+        grant_type = self.grant_type
+        cc_client_id = self.cc_client_id
+        cc_client_secret = self.cc_client_secret
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -37,6 +47,12 @@ class CreateAccountJsonBody:
         )
         if refresh_token is not UNSET:
             field_dict["refresh_token"] = refresh_token
+        if grant_type is not UNSET:
+            field_dict["grant_type"] = grant_type
+        if cc_client_id is not UNSET:
+            field_dict["cc_client_id"] = cc_client_id
+        if cc_client_secret is not UNSET:
+            field_dict["cc_client_secret"] = cc_client_secret
 
         return field_dict
 
@@ -49,10 +65,19 @@ class CreateAccountJsonBody:
 
         refresh_token = d.pop("refresh_token", UNSET)
 
+        grant_type = d.pop("grant_type", UNSET)
+
+        cc_client_id = d.pop("cc_client_id", UNSET)
+
+        cc_client_secret = d.pop("cc_client_secret", UNSET)
+
         create_account_json_body = cls(
             expires_in=expires_in,
             client=client,
             refresh_token=refresh_token,
+            grant_type=grant_type,
+            cc_client_id=cc_client_id,
+            cc_client_secret=cc_client_secret,
         )
 
         create_account_json_body.additional_properties = d
