@@ -1,7 +1,9 @@
+import datetime
 from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
@@ -18,6 +20,7 @@ class CreateVariable:
         description (str):
         account (Union[Unset, int]):
         is_oauth (Union[Unset, bool]):
+        expires_at (Union[Unset, datetime.datetime]):
     """
 
     path: str
@@ -26,6 +29,7 @@ class CreateVariable:
     description: str
     account: Union[Unset, int] = UNSET
     is_oauth: Union[Unset, bool] = UNSET
+    expires_at: Union[Unset, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -35,6 +39,9 @@ class CreateVariable:
         description = self.description
         account = self.account
         is_oauth = self.is_oauth
+        expires_at: Union[Unset, str] = UNSET
+        if not isinstance(self.expires_at, Unset):
+            expires_at = self.expires_at.isoformat()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -50,6 +57,8 @@ class CreateVariable:
             field_dict["account"] = account
         if is_oauth is not UNSET:
             field_dict["is_oauth"] = is_oauth
+        if expires_at is not UNSET:
+            field_dict["expires_at"] = expires_at
 
         return field_dict
 
@@ -68,6 +77,13 @@ class CreateVariable:
 
         is_oauth = d.pop("is_oauth", UNSET)
 
+        _expires_at = d.pop("expires_at", UNSET)
+        expires_at: Union[Unset, datetime.datetime]
+        if isinstance(_expires_at, Unset):
+            expires_at = UNSET
+        else:
+            expires_at = isoparse(_expires_at)
+
         create_variable = cls(
             path=path,
             value=value,
@@ -75,6 +91,7 @@ class CreateVariable:
             description=description,
             account=account,
             is_oauth=is_oauth,
+            expires_at=expires_at,
         )
 
         create_variable.additional_properties = d
