@@ -8,8 +8,10 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.flow_module_mock import FlowModuleMock
     from ..models.flow_module_retry import FlowModuleRetry
+    from ..models.flow_module_skip_if import FlowModuleSkipIf
     from ..models.flow_module_sleep_type_0 import FlowModuleSleepType0
     from ..models.flow_module_sleep_type_1 import FlowModuleSleepType1
+    from ..models.flow_module_stop_after_all_iters_if import FlowModuleStopAfterAllItersIf
     from ..models.flow_module_stop_after_if import FlowModuleStopAfterIf
     from ..models.flow_module_suspend import FlowModuleSuspend
 
@@ -24,6 +26,8 @@ class FlowModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, FlowModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, FlowModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, FlowModuleSkipIf]):
         sleep (Union['FlowModuleSleepType0', 'FlowModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +43,8 @@ class FlowModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "FlowModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "FlowModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "FlowModuleSkipIf"] = UNSET
     sleep: Union["FlowModuleSleepType0", "FlowModuleSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +66,14 @@ class FlowModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +116,10 @@ class FlowModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +147,10 @@ class FlowModule:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.flow_module_mock import FlowModuleMock
         from ..models.flow_module_retry import FlowModuleRetry
+        from ..models.flow_module_skip_if import FlowModuleSkipIf
         from ..models.flow_module_sleep_type_0 import FlowModuleSleepType0
         from ..models.flow_module_sleep_type_1 import FlowModuleSleepType1
+        from ..models.flow_module_stop_after_all_iters_if import FlowModuleStopAfterAllItersIf
         from ..models.flow_module_stop_after_if import FlowModuleStopAfterIf
         from ..models.flow_module_suspend import FlowModuleSuspend
 
@@ -146,6 +166,20 @@ class FlowModule:
         else:
             stop_after_if = FlowModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, FlowModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = FlowModuleStopAfterAllItersIf.from_dict(_stop_after_all_iters_if)
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, FlowModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = FlowModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(data: object) -> Union["FlowModuleSleepType0", "FlowModuleSleepType1", Unset]:
             if isinstance(data, Unset):
                 return data
@@ -212,6 +246,8 @@ class FlowModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
