@@ -14,17 +14,20 @@ class GetCompletedJobResultMaybeResponse200:
     Attributes:
         completed (bool):
         result (Any):
+        success (Union[Unset, bool]):
         started (Union[Unset, bool]):
     """
 
     completed: bool
     result: Any
+    success: Union[Unset, bool] = UNSET
     started: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         completed = self.completed
         result = self.result
+        success = self.success
         started = self.started
 
         field_dict: Dict[str, Any] = {}
@@ -35,6 +38,8 @@ class GetCompletedJobResultMaybeResponse200:
                 "result": result,
             }
         )
+        if success is not UNSET:
+            field_dict["success"] = success
         if started is not UNSET:
             field_dict["started"] = started
 
@@ -47,11 +52,14 @@ class GetCompletedJobResultMaybeResponse200:
 
         result = d.pop("result")
 
+        success = d.pop("success", UNSET)
+
         started = d.pop("started", UNSET)
 
         get_completed_job_result_maybe_response_200 = cls(
             completed=completed,
             result=result,
+            success=success,
             started=started,
         )
 
