@@ -12,6 +12,7 @@ if TYPE_CHECKING:
     from ..models.get_schedule_response_200_extra_perms import GetScheduleResponse200ExtraPerms
     from ..models.get_schedule_response_200_on_failure_extra_args import GetScheduleResponse200OnFailureExtraArgs
     from ..models.get_schedule_response_200_on_recovery_extra_args import GetScheduleResponse200OnRecoveryExtraArgs
+    from ..models.get_schedule_response_200_on_success_extra_args import GetScheduleResponse200OnSuccessExtraArgs
     from ..models.get_schedule_response_200_retry import GetScheduleResponse200Retry
 
 
@@ -41,11 +42,16 @@ class GetScheduleResponse200:
         on_recovery (Union[Unset, str]):
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, GetScheduleResponse200OnRecoveryExtraArgs]):
+        on_success (Union[Unset, str]):
+        on_success_extra_args (Union[Unset, GetScheduleResponse200OnSuccessExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
         retry (Union[Unset, GetScheduleResponse200Retry]):
         summary (Union[Unset, str]):
+        description (Union[Unset, str]):
         no_flow_overlap (Union[Unset, bool]):
         tag (Union[Unset, str]):
+        paused_until (Union[Unset, datetime.datetime]):
+        cron_version (Union[Unset, str]):
     """
 
     path: str
@@ -67,11 +73,16 @@ class GetScheduleResponse200:
     on_recovery: Union[Unset, str] = UNSET
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "GetScheduleResponse200OnRecoveryExtraArgs"] = UNSET
+    on_success: Union[Unset, str] = UNSET
+    on_success_extra_args: Union[Unset, "GetScheduleResponse200OnSuccessExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
     retry: Union[Unset, "GetScheduleResponse200Retry"] = UNSET
     summary: Union[Unset, str] = UNSET
+    description: Union[Unset, str] = UNSET
     no_flow_overlap: Union[Unset, bool] = UNSET
     tag: Union[Unset, str] = UNSET
+    paused_until: Union[Unset, datetime.datetime] = UNSET
+    cron_version: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -105,14 +116,25 @@ class GetScheduleResponse200:
         if not isinstance(self.on_recovery_extra_args, Unset):
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
+        on_success = self.on_success
+        on_success_extra_args: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.on_success_extra_args, Unset):
+            on_success_extra_args = self.on_success_extra_args.to_dict()
+
         ws_error_handler_muted = self.ws_error_handler_muted
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
 
         summary = self.summary
+        description = self.description
         no_flow_overlap = self.no_flow_overlap
         tag = self.tag
+        paused_until: Union[Unset, str] = UNSET
+        if not isinstance(self.paused_until, Unset):
+            paused_until = self.paused_until.isoformat()
+
+        cron_version = self.cron_version
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -148,16 +170,26 @@ class GetScheduleResponse200:
             field_dict["on_recovery_times"] = on_recovery_times
         if on_recovery_extra_args is not UNSET:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
+        if on_success is not UNSET:
+            field_dict["on_success"] = on_success
+        if on_success_extra_args is not UNSET:
+            field_dict["on_success_extra_args"] = on_success_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
         if retry is not UNSET:
             field_dict["retry"] = retry
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if description is not UNSET:
+            field_dict["description"] = description
         if no_flow_overlap is not UNSET:
             field_dict["no_flow_overlap"] = no_flow_overlap
         if tag is not UNSET:
             field_dict["tag"] = tag
+        if paused_until is not UNSET:
+            field_dict["paused_until"] = paused_until
+        if cron_version is not UNSET:
+            field_dict["cron_version"] = cron_version
 
         return field_dict
 
@@ -167,6 +199,7 @@ class GetScheduleResponse200:
         from ..models.get_schedule_response_200_extra_perms import GetScheduleResponse200ExtraPerms
         from ..models.get_schedule_response_200_on_failure_extra_args import GetScheduleResponse200OnFailureExtraArgs
         from ..models.get_schedule_response_200_on_recovery_extra_args import GetScheduleResponse200OnRecoveryExtraArgs
+        from ..models.get_schedule_response_200_on_success_extra_args import GetScheduleResponse200OnSuccessExtraArgs
         from ..models.get_schedule_response_200_retry import GetScheduleResponse200Retry
 
         d = src_dict.copy()
@@ -223,6 +256,15 @@ class GetScheduleResponse200:
         else:
             on_recovery_extra_args = GetScheduleResponse200OnRecoveryExtraArgs.from_dict(_on_recovery_extra_args)
 
+        on_success = d.pop("on_success", UNSET)
+
+        _on_success_extra_args = d.pop("on_success_extra_args", UNSET)
+        on_success_extra_args: Union[Unset, GetScheduleResponse200OnSuccessExtraArgs]
+        if isinstance(_on_success_extra_args, Unset):
+            on_success_extra_args = UNSET
+        else:
+            on_success_extra_args = GetScheduleResponse200OnSuccessExtraArgs.from_dict(_on_success_extra_args)
+
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
         _retry = d.pop("retry", UNSET)
@@ -234,10 +276,21 @@ class GetScheduleResponse200:
 
         summary = d.pop("summary", UNSET)
 
+        description = d.pop("description", UNSET)
+
         no_flow_overlap = d.pop("no_flow_overlap", UNSET)
 
         tag = d.pop("tag", UNSET)
 
+        _paused_until = d.pop("paused_until", UNSET)
+        paused_until: Union[Unset, datetime.datetime]
+        if isinstance(_paused_until, Unset):
+            paused_until = UNSET
+        else:
+            paused_until = isoparse(_paused_until)
+
+        cron_version = d.pop("cron_version", UNSET)
+
         get_schedule_response_200 = cls(
             path=path,
             edited_by=edited_by,
@@ -258,11 +311,16 @@ class GetScheduleResponse200:
             on_recovery=on_recovery,
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
+            on_success=on_success,
+            on_success_extra_args=on_success_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
             retry=retry,
             summary=summary,
+            description=description,
             no_flow_overlap=no_flow_overlap,
             tag=tag,
+            paused_until=paused_until,
+            cron_version=cron_version,
         )
 
         get_schedule_response_200.additional_properties = d
