@@ -9,6 +9,9 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.get_script_by_path_with_draft_response_200_draft import GetScriptByPathWithDraftResponse200Draft
+    from ..models.get_script_by_path_with_draft_response_200_fallback_access_types_item import (
+        GetScriptByPathWithDraftResponse200FallbackAccessTypesItem,
+    )
     from ..models.get_script_by_path_with_draft_response_200_schema import GetScriptByPathWithDraftResponse200Schema
 
 
@@ -49,6 +52,7 @@ class GetScriptByPathWithDraftResponse200:
         codebase (Union[Unset, str]):
         has_preprocessor (Union[Unset, bool]):
         on_behalf_of_email (Union[Unset, str]):
+        fallback_access_types (Union[Unset, List['GetScriptByPathWithDraftResponse200FallbackAccessTypesItem']]):
         draft (Union[Unset, GetScriptByPathWithDraftResponse200Draft]):
     """
 
@@ -82,6 +86,7 @@ class GetScriptByPathWithDraftResponse200:
     codebase: Union[Unset, str] = UNSET
     has_preprocessor: Union[Unset, bool] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
+    fallback_access_types: Union[Unset, List["GetScriptByPathWithDraftResponse200FallbackAccessTypesItem"]] = UNSET
     draft: Union[Unset, "GetScriptByPathWithDraftResponse200Draft"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -126,6 +131,14 @@ class GetScriptByPathWithDraftResponse200:
         codebase = self.codebase
         has_preprocessor = self.has_preprocessor
         on_behalf_of_email = self.on_behalf_of_email
+        fallback_access_types: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.fallback_access_types, Unset):
+            fallback_access_types = []
+            for fallback_access_types_item_data in self.fallback_access_types:
+                fallback_access_types_item = fallback_access_types_item_data.to_dict()
+
+                fallback_access_types.append(fallback_access_types_item)
+
         draft: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.draft, Unset):
             draft = self.draft.to_dict()
@@ -190,6 +203,8 @@ class GetScriptByPathWithDraftResponse200:
             field_dict["has_preprocessor"] = has_preprocessor
         if on_behalf_of_email is not UNSET:
             field_dict["on_behalf_of_email"] = on_behalf_of_email
+        if fallback_access_types is not UNSET:
+            field_dict["fallback_access_types"] = fallback_access_types
         if draft is not UNSET:
             field_dict["draft"] = draft
 
@@ -198,6 +213,9 @@ class GetScriptByPathWithDraftResponse200:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.get_script_by_path_with_draft_response_200_draft import GetScriptByPathWithDraftResponse200Draft
+        from ..models.get_script_by_path_with_draft_response_200_fallback_access_types_item import (
+            GetScriptByPathWithDraftResponse200FallbackAccessTypesItem,
+        )
         from ..models.get_script_by_path_with_draft_response_200_schema import GetScriptByPathWithDraftResponse200Schema
 
         d = src_dict.copy()
@@ -271,6 +289,15 @@ class GetScriptByPathWithDraftResponse200:
 
         on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
 
+        fallback_access_types = []
+        _fallback_access_types = d.pop("fallback_access_types", UNSET)
+        for fallback_access_types_item_data in _fallback_access_types or []:
+            fallback_access_types_item = GetScriptByPathWithDraftResponse200FallbackAccessTypesItem.from_dict(
+                fallback_access_types_item_data
+            )
+
+            fallback_access_types.append(fallback_access_types_item)
+
         _draft = d.pop("draft", UNSET)
         draft: Union[Unset, GetScriptByPathWithDraftResponse200Draft]
         if isinstance(_draft, Unset):
@@ -309,6 +336,7 @@ class GetScriptByPathWithDraftResponse200:
             codebase=codebase,
             has_preprocessor=has_preprocessor,
             on_behalf_of_email=on_behalf_of_email,
+            fallback_access_types=fallback_access_types,
             draft=draft,
         )
 
