@@ -9,6 +9,7 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.new_script_with_draft_draft import NewScriptWithDraftDraft
+    from ..models.new_script_with_draft_fallback_access_types_item import NewScriptWithDraftFallbackAccessTypesItem
     from ..models.new_script_with_draft_schema import NewScriptWithDraftSchema
 
 
@@ -49,6 +50,7 @@ class NewScriptWithDraft:
         codebase (Union[Unset, str]):
         has_preprocessor (Union[Unset, bool]):
         on_behalf_of_email (Union[Unset, str]):
+        fallback_access_types (Union[Unset, List['NewScriptWithDraftFallbackAccessTypesItem']]):
         draft (Union[Unset, NewScriptWithDraftDraft]):
     """
 
@@ -82,6 +84,7 @@ class NewScriptWithDraft:
     codebase: Union[Unset, str] = UNSET
     has_preprocessor: Union[Unset, bool] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
+    fallback_access_types: Union[Unset, List["NewScriptWithDraftFallbackAccessTypesItem"]] = UNSET
     draft: Union[Unset, "NewScriptWithDraftDraft"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -126,6 +129,14 @@ class NewScriptWithDraft:
         codebase = self.codebase
         has_preprocessor = self.has_preprocessor
         on_behalf_of_email = self.on_behalf_of_email
+        fallback_access_types: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.fallback_access_types, Unset):
+            fallback_access_types = []
+            for fallback_access_types_item_data in self.fallback_access_types:
+                fallback_access_types_item = fallback_access_types_item_data.to_dict()
+
+                fallback_access_types.append(fallback_access_types_item)
+
         draft: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.draft, Unset):
             draft = self.draft.to_dict()
@@ -190,6 +201,8 @@ class NewScriptWithDraft:
             field_dict["has_preprocessor"] = has_preprocessor
         if on_behalf_of_email is not UNSET:
             field_dict["on_behalf_of_email"] = on_behalf_of_email
+        if fallback_access_types is not UNSET:
+            field_dict["fallback_access_types"] = fallback_access_types
         if draft is not UNSET:
             field_dict["draft"] = draft
 
@@ -198,6 +211,7 @@ class NewScriptWithDraft:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.new_script_with_draft_draft import NewScriptWithDraftDraft
+        from ..models.new_script_with_draft_fallback_access_types_item import NewScriptWithDraftFallbackAccessTypesItem
         from ..models.new_script_with_draft_schema import NewScriptWithDraftSchema
 
         d = src_dict.copy()
@@ -271,6 +285,15 @@ class NewScriptWithDraft:
 
         on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
 
+        fallback_access_types = []
+        _fallback_access_types = d.pop("fallback_access_types", UNSET)
+        for fallback_access_types_item_data in _fallback_access_types or []:
+            fallback_access_types_item = NewScriptWithDraftFallbackAccessTypesItem.from_dict(
+                fallback_access_types_item_data
+            )
+
+            fallback_access_types.append(fallback_access_types_item)
+
         _draft = d.pop("draft", UNSET)
         draft: Union[Unset, NewScriptWithDraftDraft]
         if isinstance(_draft, Unset):
@@ -309,6 +332,7 @@ class NewScriptWithDraft:
             codebase=codebase,
             has_preprocessor=has_preprocessor,
             on_behalf_of_email=on_behalf_of_email,
+            fallback_access_types=fallback_access_types,
             draft=draft,
         )
 
