@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.open_flow_value_failure_module_mock import OpenFlowValueFailureModuleMock
     from ..models.open_flow_value_failure_module_retry import OpenFlowValueFailureModuleRetry
+    from ..models.open_flow_value_failure_module_skip_if import OpenFlowValueFailureModuleSkipIf
     from ..models.open_flow_value_failure_module_sleep_type_0 import OpenFlowValueFailureModuleSleepType0
     from ..models.open_flow_value_failure_module_sleep_type_1 import OpenFlowValueFailureModuleSleepType1
+    from ..models.open_flow_value_failure_module_stop_after_all_iters_if import (
+        OpenFlowValueFailureModuleStopAfterAllItersIf,
+    )
     from ..models.open_flow_value_failure_module_stop_after_if import OpenFlowValueFailureModuleStopAfterIf
     from ..models.open_flow_value_failure_module_suspend import OpenFlowValueFailureModuleSuspend
 
@@ -24,6 +28,8 @@ class OpenFlowValueFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, OpenFlowValueFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, OpenFlowValueFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, OpenFlowValueFailureModuleSkipIf]):
         sleep (Union['OpenFlowValueFailureModuleSleepType0', 'OpenFlowValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class OpenFlowValueFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "OpenFlowValueFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "OpenFlowValueFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "OpenFlowValueFailureModuleSkipIf"] = UNSET
     sleep: Union["OpenFlowValueFailureModuleSleepType0", "OpenFlowValueFailureModuleSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class OpenFlowValueFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class OpenFlowValueFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class OpenFlowValueFailureModule:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.open_flow_value_failure_module_mock import OpenFlowValueFailureModuleMock
         from ..models.open_flow_value_failure_module_retry import OpenFlowValueFailureModuleRetry
+        from ..models.open_flow_value_failure_module_skip_if import OpenFlowValueFailureModuleSkipIf
         from ..models.open_flow_value_failure_module_sleep_type_0 import OpenFlowValueFailureModuleSleepType0
         from ..models.open_flow_value_failure_module_sleep_type_1 import OpenFlowValueFailureModuleSleepType1
+        from ..models.open_flow_value_failure_module_stop_after_all_iters_if import (
+            OpenFlowValueFailureModuleStopAfterAllItersIf,
+        )
         from ..models.open_flow_value_failure_module_stop_after_if import OpenFlowValueFailureModuleStopAfterIf
         from ..models.open_flow_value_failure_module_suspend import OpenFlowValueFailureModuleSuspend
 
@@ -146,6 +170,20 @@ class OpenFlowValueFailureModule:
         else:
             stop_after_if = OpenFlowValueFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, OpenFlowValueFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = OpenFlowValueFailureModuleStopAfterAllItersIf.from_dict(_stop_after_all_iters_if)
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, OpenFlowValueFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = OpenFlowValueFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["OpenFlowValueFailureModuleSleepType0", "OpenFlowValueFailureModuleSleepType1", Unset]:
@@ -214,6 +252,8 @@ class OpenFlowValueFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
