@@ -8,6 +8,7 @@ from ..models.raw_script_type import RawScriptType
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.raw_script_asset_fallback_access_types_item import RawScriptAssetFallbackAccessTypesItem
     from ..models.raw_script_input_transforms import RawScriptInputTransforms
 
 
@@ -29,6 +30,7 @@ class RawScript:
         concurrency_time_window_s (Union[Unset, float]):
         custom_concurrency_key (Union[Unset, str]):
         is_trigger (Union[Unset, bool]):
+        asset_fallback_access_types (Union[Unset, List['RawScriptAssetFallbackAccessTypesItem']]):
     """
 
     input_transforms: "RawScriptInputTransforms"
@@ -42,6 +44,7 @@ class RawScript:
     concurrency_time_window_s: Union[Unset, float] = UNSET
     custom_concurrency_key: Union[Unset, str] = UNSET
     is_trigger: Union[Unset, bool] = UNSET
+    asset_fallback_access_types: Union[Unset, List["RawScriptAssetFallbackAccessTypesItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -59,6 +62,13 @@ class RawScript:
         concurrency_time_window_s = self.concurrency_time_window_s
         custom_concurrency_key = self.custom_concurrency_key
         is_trigger = self.is_trigger
+        asset_fallback_access_types: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.asset_fallback_access_types, Unset):
+            asset_fallback_access_types = []
+            for asset_fallback_access_types_item_data in self.asset_fallback_access_types:
+                asset_fallback_access_types_item = asset_fallback_access_types_item_data.to_dict()
+
+                asset_fallback_access_types.append(asset_fallback_access_types_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -84,11 +94,14 @@ class RawScript:
             field_dict["custom_concurrency_key"] = custom_concurrency_key
         if is_trigger is not UNSET:
             field_dict["is_trigger"] = is_trigger
+        if asset_fallback_access_types is not UNSET:
+            field_dict["asset_fallback_access_types"] = asset_fallback_access_types
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.raw_script_asset_fallback_access_types_item import RawScriptAssetFallbackAccessTypesItem
         from ..models.raw_script_input_transforms import RawScriptInputTransforms
 
         d = src_dict.copy()
@@ -114,6 +127,15 @@ class RawScript:
 
         is_trigger = d.pop("is_trigger", UNSET)
 
+        asset_fallback_access_types = []
+        _asset_fallback_access_types = d.pop("asset_fallback_access_types", UNSET)
+        for asset_fallback_access_types_item_data in _asset_fallback_access_types or []:
+            asset_fallback_access_types_item = RawScriptAssetFallbackAccessTypesItem.from_dict(
+                asset_fallback_access_types_item_data
+            )
+
+            asset_fallback_access_types.append(asset_fallback_access_types_item)
+
         raw_script = cls(
             input_transforms=input_transforms,
             content=content,
@@ -126,6 +148,7 @@ class RawScript:
             concurrency_time_window_s=concurrency_time_window_s,
             custom_concurrency_key=custom_concurrency_key,
             is_trigger=is_trigger,
+            asset_fallback_access_types=asset_fallback_access_types,
         )
 
         raw_script.additional_properties = d
