@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.run_flow_preview_json_body_value_failure_module_retry import (
         RunFlowPreviewJsonBodyValueFailureModuleRetry,
     )
+    from ..models.run_flow_preview_json_body_value_failure_module_skip_if import (
+        RunFlowPreviewJsonBodyValueFailureModuleSkipIf,
+    )
     from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_0 import (
         RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
     )
     from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_1 import (
         RunFlowPreviewJsonBodyValueFailureModuleSleepType1,
     )
+    from ..models.run_flow_preview_json_body_value_failure_module_stop_after_all_iters_if import (
+        RunFlowPreviewJsonBodyValueFailureModuleStopAfterAllItersIf,
+    )
     from ..models.run_flow_preview_json_body_value_failure_module_stop_after_if import (
         RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf,
     )
@@ -36,6 +42,8 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleSkipIf]):
         sleep (Union['RunFlowPreviewJsonBodyValueFailureModuleSleepType0',
             'RunFlowPreviewJsonBodyValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class RunFlowPreviewJsonBodyValueFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "RunFlowPreviewJsonBodyValueFailureModuleSkipIf"] = UNSET
     sleep: Union[
         "RunFlowPreviewJsonBodyValueFailureModuleSleepType0",
         "RunFlowPreviewJsonBodyValueFailureModuleSleepType1",
@@ -79,6 +89,14 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         from ..models.run_flow_preview_json_body_value_failure_module_retry import (
             RunFlowPreviewJsonBodyValueFailureModuleRetry,
         )
+        from ..models.run_flow_preview_json_body_value_failure_module_skip_if import (
+            RunFlowPreviewJsonBodyValueFailureModuleSkipIf,
+        )
         from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_0 import (
             RunFlowPreviewJsonBodyValueFailureModuleSleepType0,
         )
         from ..models.run_flow_preview_json_body_value_failure_module_sleep_type_1 import (
             RunFlowPreviewJsonBodyValueFailureModuleSleepType1,
         )
+        from ..models.run_flow_preview_json_body_value_failure_module_stop_after_all_iters_if import (
+            RunFlowPreviewJsonBodyValueFailureModuleStopAfterAllItersIf,
+        )
         from ..models.run_flow_preview_json_body_value_failure_module_stop_after_if import (
             RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf,
         )
@@ -177,6 +205,22 @@ class RunFlowPreviewJsonBodyValueFailureModule:
         else:
             stop_after_if = RunFlowPreviewJsonBodyValueFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = RunFlowPreviewJsonBodyValueFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, RunFlowPreviewJsonBodyValueFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = RunFlowPreviewJsonBodyValueFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class RunFlowPreviewJsonBodyValueFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
