@@ -1,13 +1,14 @@
 from typing import Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="UpdateUserJsonBody")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class UpdateUserJsonBody:
     """
     Attributes:
@@ -19,7 +20,7 @@ class UpdateUserJsonBody:
     is_admin: Union[Unset, bool] = UNSET
     operator: Union[Unset, bool] = UNSET
     disabled: Union[Unset, bool] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         is_admin = self.is_admin
